@@ -25,7 +25,7 @@ Implementation Notes
 # pylint:disable=invalid-name,redefined-builtin,attribute-defined-outside-init
 # pylint:disable=stop-iteration-return,anomalous-backslash-in-string
 
-__version__ = "2.0.3"
+__version__ = "2.0.4"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Itertools.git"
 
 
@@ -263,9 +263,7 @@ class groupby:
     # [list(g) for k, g in groupby('AAAABBBCCD')] --> AAAA BBB CC D
 
     def __init__(self, iterable, key=None):
-        if key is None:
-            key = lambda x: x
-        self.keyfunc = key
+        self.keyfunc = key if key is not None else lambda x: x
         self.it = iter(iterable)
         self.tgtkey = self.currkey = self.currvalue = object()
 
